@@ -37,6 +37,11 @@ class TornadoAsyncSolrClient(object):
         self.client.fetch(request, _callback)
 
     def select(self, query, callback=None, **kwargs):
+        try:
+            query = query.encode('utf8')
+        except ValueError:
+            pass
+
         kwargs['q'] = query
         kwargs['wt'] = 'json'
         self.request('GET', "%s?%s" % (self.select_url, urllib.urlencode(kwargs, 1)), callback=callback)
